@@ -1,5 +1,5 @@
 ### log-likelihood function, except for gaussian family
-logLik.glmreg <- function(object, newx, y, weights, na.action=na.pass, ...){
+logLik.glmreg <- function(object, newx, y, weights, offset, na.action=na.pass, ...){
 if(missing(newx) || missing(y)) return(object$twologlik/2)
 if(!is.null(object$terms)){
  mf <- model.frame(delete.response(object$terms), newx, na.action = na.action, xlev = object$xlevels)
@@ -10,6 +10,8 @@ family <- object$family
 nlambda <- object$nlambda
 beta <- object$beta
 b0 <- object$b0
+if(missing(offset))
+ offset <- object$offset
 famtype <- switch(family,
       "gaussian"=1,
       "binomial"=2,
@@ -31,6 +33,7 @@ w <- weights
  x=as.double(newx),
  b=as.double(beta),
  a0=as.double(b0),
+ offset=as.double(offset),
  family=as.integer(famtype),
  eta=as.double(matrix(0, nobs, nlambda)),
  mu=as.double(matrix(0, nobs, nlambda)),
